@@ -1,6 +1,6 @@
 package Koha::Contrib::Sudoc::Koha;
 # ABSTRACT: Lien à Koha
-$Koha::Contrib::Sudoc::Koha::VERSION = '2.41';
+$Koha::Contrib::Sudoc::Koha::VERSION = '2.42';
 use Moose;
 use Modern::Perl;
 use Carp;
@@ -333,8 +333,9 @@ sub get_auth_by_ppn {
                 query => {  match => { ppn => $ppn }  }
             }
         );
-        if ( $res->{hits}->{total} != 0 ) {
-            my $source = $res->{hits}->{hits}->[0]->{_source};
+        my $hits = $res->{hits}->{hits};
+        if ( @$hits != 0 ) {
+            my $source = $hits->[0]->{_source};
             $record = _record_from_es($source);
         }
     }
@@ -369,7 +370,7 @@ Koha::Contrib::Sudoc::Koha - Lien à Koha
 
 =head1 VERSION
 
-version 2.41
+version 2.42
 
 =head1 DESCRIPTION
 
